@@ -10,14 +10,17 @@ If that URL should fail, try contacting the author.
 Contributors:
     Antoine Taillefer
     Rémi Cattiau
-    Mickaël Schoentgen <mschoentgen@nuxeo.com>
+    Mickaël Schoentgen
     Léa Klein
     Romain Grasland
+    Anindya Roy
+    Sweta Yadav
+    Shekhar Gupta
     and https://github.com/nuxeo/nuxeo-python-client/graphs/contributors
 """
 
 __author__ = "Nuxeo"
-__version__ = "6.0.0"
+__version__ = "6.1.0"
 __copyright__ = """
     Copyright Nuxeo (https://www.nuxeo.com) and others.
 
