@@ -1,40 +1,29 @@
 # coding: utf-8
-from __future__ import unicode_literals
 import base64
+from requests import Request
 
-from ..compat import get_bytes, get_text
 from .base import AuthBase
 
-try:
-    from typing import TYPE_CHECKING
-
-    if TYPE_CHECKING:
-        from typing import Text
-        from requests import Request
-except ImportError:
-    pass
-
 
 class BasicAuth(AuthBase):
     """ Attaches a simple Basic Authentication to the given Request object. """
 
     __slots__ = ("username", "password", "_token_header")
 
-    AUTHORIZATION = get_bytes("Authorization")
+    AUTHORIZATION = "Authorization".encode("utf-8")
 
     def __init__(self, username, password):
-        # type: (Text, Text) -> None
+        # type: (str, str) -> None
         self.username = username
         self.password = password
         self.set_token(password)
 
     def set_token(self, token):
-        # type: (Text) -> None
+        # type: (str) -> None
         """Apply the given *token*."""
         self.password = token
-        self._token_header = "Basic " + get_text(
-            base64.b64encode(get_bytes(self.username + ":" + self.password))
-        )
+        payload = f"{self.username}:{self.password}".encode("utf-8")
+        self._token_header = f"Basic {base64.b64encode(payload).decode('utf-8')}"
 
     def __eq__(self, other):
         # type: (object) -> bool
