@@ -15,7 +15,7 @@ if TYPE_CHECKING:
 
 
 class Model(object):
-    """ Base class for all entities. """
+    """Base class for all entities."""
 
     __slots__ = {"service": None}  # type: Dict[str, Any]
 
@@ -43,7 +43,7 @@ class Model(object):
 
     def as_dict(self):
         # type: () -> Dict[str, Any]
-        """ Returns a dict representation of the resource. """
+        """Returns a dict representation of the resource."""
         result = {}
         for key in self.__slots__:
             val = getattr(self, key)
@@ -59,13 +59,13 @@ class Model(object):
     @classmethod
     def parse(cls, json, service=None):
         # type: (Dict[str, Any], Optional[APIEndpoint]) -> Model
-        """ Parse a JSON object into a model instance. """
+        """Parse a JSON object into a model instance."""
         kwargs = {k: v for k, v in json.items()}
         return cls(service=service, **kwargs)
 
     def save(self):
         # type: () -> None
-        """ Save the resource. """
+        """Save the resource."""
         self.service.put(self)
 
 
@@ -105,7 +105,7 @@ class RefreshableModel(Model):
 
 
 class Batch(Model):
-    """ Upload batch. """
+    """Upload batch."""
 
     __slots__ = {
         "batchId": None,
@@ -131,20 +131,20 @@ class Batch(Model):
 
     def cancel(self):
         # type: () -> None
-        """ Cancel an upload batch. """
+        """Cancel an upload batch."""
         if not self.batchId:
             return
         self.service.delete(self.uid)
         self.batchId = None
 
-    def delete(self, file_idx):
-        """ Delete a blob from the batch. """
+    def delete(self, file_idx, ssl_verify=True):
+        """Delete a blob from the batch."""
         if self.batchId:
-            self.service.delete(self.uid, file_idx=file_idx)
+            self.service.delete(self.uid, file_idx=file_idx, ssl_verify=ssl_verify)
             self.blobs[file_idx] = None
 
-    def get(self, file_idx):
-        # type: (int) -> Blob
+    def get(self, file_idx, ssl_verify=True):
+        # type: (int, bool) -> Blob
         """
         Get the blob info.
 
@@ -153,12 +153,12 @@ class Batch(Model):
         """
         if self.batchId is None:
             raise InvalidBatch("Cannot fetch blob for inexistant/deleted batch.")
-        blob = self.service.get(self.uid, file_idx=file_idx)
+        blob = self.service.get(self.uid, file_idx=file_idx, ssl_verify=ssl_verify)
         self.blobs[file_idx] = blob
         return blob
 
-    def get_uploader(self, blob, **kwargs):
-        # type: (Blob, Any) -> Blob
+    def get_uploader(self, blob, ssl_verify=True, **kwargs):
+        # type: (Blob, bool, Any) -> Blob
         """
         Get an uploader for blob.
 
@@ -171,10 +171,17 @@ class Batch(Model):
     def is_s3(self):
         # type: () -> bool
         """Return True if the upload provider is Amazon S3."""
-        return self.provider == UP_AMAZON_S3
+        provider = self.provider or ""
+        if not provider:
+            return False
 
-    def upload(self, blob, **kwargs):
-        # type: (Blob, Any) -> Blob
+        if isinstance(self.extraInfo, dict):
+            provider = self.extraInfo.get("provider_type", "") or provider
+
+        return provider.lower() == UP_AMAZON_S3
+
+    def upload(self, blob, ssl_verify=True, **kwargs):
+        # type: (Blob, bool, Any) -> Blob
         """
         Upload a blob.
 
@@ -182,10 +189,10 @@ class Batch(Model):
         :param kwargs: the upload settings
         :return: the blob info
         """
-        return self.service.upload(self, blob, **kwargs)
+        return self.service.upload(self, blob, ssl_verify=ssl_verify, **kwargs)
 
-    def execute(self, operation, file_idx=None, params=None):
-        # type: (str, int, Dict[str, Any]) -> Any
+    def execute(self, operation, file_idx=None, params=None, ssl_verify=True):
+        # type: (str, int, Dict[str, Any], bool) -> Any
         """
         Execute an operation on this batch.
 
@@ -194,10 +201,12 @@ class Batch(Model):
         :param params: parameters of the operation
         :return: the output of the operation
         """
-        return self.service.execute(self, operation, file_idx, params)
+        return self.service.execute(
+            self, operation, file_idx, params, ssl_verify=ssl_verify
+        )
 
-    def attach(self, doc, file_idx=None):
-        # type: (str, Optional[int]) -> Any
+    def attach(self, doc, file_idx=None, ssl_verify=True):
+        # type: (str, Optional[int], bool) -> Any
         """
         Attach one or all files of this batch to a document.
 
@@ -205,21 +214,21 @@ class Batch(Model):
         :param file_idx: target file
         :return: the output of the attach operation
         """
-        return self.service.attach(self, doc, file_idx)
+        return self.service.attach(self, doc, file_idx, ssl_verify=ssl_verify)
 
-    def complete(self, **kwargs):
-        # type: (Any) -> Any
+    def complete(self, ssl_verify=True, **kwargs):
+        # type: (bool, Any) -> Any
         """
         Complete a S3 Direct Upload.
 
         :param kwargs: additional arguments fowarded at the underlying level
         :return: the output of the complete operation
         """
-        return self.service.complete(self, **kwargs)
+        return self.service.complete(self, ssl_verify=ssl_verify, **kwargs)
 
 
 class Blob(Model):
-    """ Blob superclass used for metadata. """
+    """Blob superclass used for metadata."""
 
     __slots__ = {
         "batchId": "",
@@ -237,7 +246,7 @@ class Blob(Model):
     @classmethod
     def parse(cls, json, service=None):
         # type: (Dict[str, Any], Optional[APIEndpoint]) -> Blob
-        """ Parse a JSON object into a blob instance. """
+        """Parse a JSON object into a blob instance."""
         kwargs = {k: v for k, v in json.items()}
         model = cls(service=service, **kwargs)
 
@@ -247,7 +256,7 @@ class Blob(Model):
 
     def to_json(self):
         # type: () -> Dict[str, str]
-        """ Return a JSON object used during the upload. """
+        """Return a JSON object used during the upload."""
         return {"upload-batch": self.batchId, "upload-fileId": str(self.fileIdx)}
 
 
@@ -274,7 +283,7 @@ class BufferBlob(Blob):
     @property
     def data(self):
         # type: () -> StringIO
-        """ Request data. """
+        """Request data."""
         return self.stringio
 
     def __enter__(self):
@@ -289,7 +298,7 @@ class BufferBlob(Blob):
 
 
 class Comment(Model):
-    """ Comment. """
+    """Comment."""
 
     __slots__ = {
         "ancestorIds": [],
@@ -312,14 +321,14 @@ class Comment(Model):
         # type: () -> str
         return self.id
 
-    def delete(self):
-        # type: () -> None
-        """ Delete the comment. """
-        self.service.delete(self.uid)
+    def delete(self, ssl_verify=True):
+        # type: (bool) -> None
+        """Delete the comment."""
+        self.service.delete(self.uid, ssl_verify=ssl_verify)
 
     def has_replies(self):
         # type: () -> bool
-        """ Return True is the comment has at least one reply. """
+        """Return True is the comment has at least one reply."""
         return self.numberOfReplies > 0
 
     def replies(self, **params):
@@ -336,7 +345,7 @@ class Comment(Model):
 
     def reply(self, text):
         # type: (str) -> Comment
-        """ Add a reply to the comment. """
+        """Add a reply to the comment."""
         # Add the reply
         reply_comment = self.service.post(self.uid, text)
 
@@ -391,7 +400,7 @@ class FileBlob(Blob):
 
 
 class Directory(Model):
-    """ Directory. """
+    """Directory."""
 
     __slots__ = {
         "directoryName": None,
@@ -416,12 +425,12 @@ class Directory(Model):
 
     def create(self, entry):
         # type: (DirectoryEntry) -> DirectoryEntry
-        """ Create an entry in the directory. """
+        """Create an entry in the directory."""
         return self.service.post(entry, dir_name=self.uid)
 
     def save(self, entry):
         # type: (DirectoryEntry) -> DirectoryEntry
-        """ Save a modified entry of the directory. """
+        """Save a modified entry of the directory."""
         return self.service.put(entry, dir_name=self.uid)
 
     def delete(self, entry):
@@ -445,7 +454,7 @@ class Directory(Model):
 
 
 class DirectoryEntry(Model):
-    """ Directory entry. """
+    """Directory entry."""
 
     __slots__ = {
         "directoryName": None,
@@ -460,17 +469,17 @@ class DirectoryEntry(Model):
 
     def save(self):
         # type: () -> DirectoryEntry
-        """ Save the entry. """
+        """Save the entry."""
         return self.service.put(self, self.directoryName)
 
     def delete(self):
         # type: () -> None
-        """ Delete the entry. """
+        """Delete the entry."""
         self.service.delete(self.directoryName, self.uid)
 
 
 class Document(RefreshableModel):
-    """ Document. """
+    """Document."""
 
     __slots__ = {
         "changeToken": None,
@@ -497,11 +506,11 @@ class Document(RefreshableModel):
     @property
     def workflows(self):
         # type: () -> List[Workflow]
-        """ Return the workflows associated with the document. """
+        """Return the workflows associated with the document."""
         return self.service.workflows(self)
 
-    def add_permission(self, params):
-        # type: (Dict[str, Any]) -> None
+    def add_permission(self, params, ssl_verify=True):
+        # type: (Dict[str, Any], bool) -> None
         """
         Add a permission to a document.
 
@@ -509,80 +518,81 @@ class Document(RefreshableModel):
         """
         return self.service.add_permission(self.uid, params)
 
-    def comment(self, text):
-        # type: (str) -> Comment
+    def comment(self, text, ssl_verify=True):
+        # type: (str, bool) -> Comment
         """
         Add a comment to the document.
 
         :param text: the comment message
         :return: a comment object
         """
-        return self.service.comment(self.uid, text)
+        return self.service.comment(self.uid, text, ssl_verify=ssl_verify)
 
-    def comments(self, **params):
-        # type: (Any) -> List[Comment]
+    def comments(self, ssl_verify=True, **params):
+        # type: (bool, Any) -> List[Comment]
         """Return the comments associated with the document.
         Any additionnal arguments will be passed to the *params* parent's call.
         """
-        return self.service.comments(self.uid, params=params)
+        return self.service.comments(self.uid, params=params, ssl_verify=ssl_verify)
 
-    def convert(self, params):
-        # type: (Dict[str, Any]) -> Union[Dict[str, Any], str]
+    def convert(self, params, ssl_verify=True):
+        # type: (Dict[str, Any], bool) -> Union[Dict[str, Any], str]
         """
         Convert the document to another format.
 
         :param params: Converter permission
         :return: the converter result
         """
+
         return self.service.convert(self.uid, params)
 
-    def delete(self):
-        # type: () -> None
-        """ Delete the document. """
-        self.service.delete(self.uid)
+    def delete(self, ssl_verify=True):
+        # type: (bool) -> None
+        """Delete the document."""
+        self.service.delete(self.uid, ssl_verify=ssl_verify)
 
-    def fetch_acls(self):
-        # type: () -> Dict[str, Any]
-        """ Fetch document ACLs. """
-        return self.service.fetch_acls(self.uid)
+    def fetch_acls(self, ssl_verify=True):
+        # type: (bool) -> Dict[str, Any]
+        """Fetch document ACLs."""
+        return self.service.fetch_acls(self.uid, ssl_verify=ssl_verify)
 
-    def fetch_audit(self):
-        # type: () -> Dict[str, Any]
-        """ Fetch audit for current document. """
-        return self.service.fetch_audit(self.uid)
+    def fetch_audit(self, ssl_verify=True):
+        # type: (bool) -> Dict[str, Any]
+        """Fetch audit for current document."""
+        return self.service.fetch_audit(self.uid, ssl_verify=ssl_verify)
 
-    def fetch_blob(self, xpath="blobholder:0"):
-        # type: (str) -> Blob
+    def fetch_blob(self, xpath="blobholder:0", ssl_verify=True):
+        # type: (str, bool) -> Blob
         """
         Retrieve one of the blobs attached to the document.
 
         :param xpath: the xpath to the blob
         :return: the blob
         """
-        return self.service.fetch_blob(uid=self.uid, xpath=xpath)
+        return self.service.fetch_blob(uid=self.uid, xpath=xpath, ssl_verify=ssl_verify)
 
-    def fetch_lock_status(self):
-        # type: () -> Dict[str, Any]
-        """ Get lock informations. """
+    def fetch_lock_status(self, ssl_verify=True):
+        # type: (bool) -> Dict[str, Any]
+        """Get lock informations."""
         return self.service.fetch_lock_status(self.uid)
 
-    def fetch_rendition(self, name):
-        # type: (str) -> Union[str, bytes]
+    def fetch_rendition(self, name, ssl_verify=True):
+        # type: (str, bool) -> Union[str, bytes]
         """
         :param name: Rendition name to use
         :return: The rendition content
         """
-        return self.service.fetch_rendition(self.uid, name)
+        return self.service.fetch_rendition(self.uid, name, ssl_verify=ssl_verify)
 
-    def fetch_renditions(self):
-        # type: () -> List[Union[str, bytes]]
+    def fetch_renditions(self, ssl_verify=True):
+        # type: (bool) -> List[Union[str, bytes]]
         """
         :return: Available renditions for this document
         """
-        return self.service.fetch_renditions(self.uid)
+        return self.service.fetch_renditions(self.uid, ssl_verify=ssl_verify)
 
-    def follow_transition(self, name):
-        # type: (str) -> None
+    def follow_transition(self, name, ssl_verify=True):
+        # type: (str, bool) -> None
         """
         Follow a lifecycle transition on this document.
 
@@ -593,26 +603,26 @@ class Document(RefreshableModel):
 
     def get(self, prop):
         # type: (str) -> Any
-        """ Get a property of the document by its name. """
+        """Get a property of the document by its name."""
         return self.properties[prop]
 
-    def has_permission(self, permission):
-        # type: (str) -> bool
-        """ Verify if a document has the permission. """
+    def has_permission(self, permission, ssl_verify=True):
+        # type: (str, bool) -> bool
+        """Verify if a document has the permission."""
         return self.service.has_permission(self.uid, permission)
 
     def is_locked(self):
         # type: () -> bool
-        """ Get the lock status. """
+        """Get the lock status."""
         return not not self.fetch_lock_status()
 
-    def lock(self):
-        # type: () -> Dict[str, Any]
-        """ Lock the document. """
+    def lock(self, ssl_verify=True):
+        # type: (bool) -> Dict[str, Any]
+        """Lock the document."""
         return self.service.lock(self.uid)
 
-    def move(self, dst, name=None):
-        # type: (str, Optional[str]) -> None
+    def move(self, dst, name=None, ssl_verify=True):
+        # type: (str, Optional[str], bool) -> None
         """
         Move a document into another parent.
 
@@ -622,34 +632,34 @@ class Document(RefreshableModel):
         doc = self.service.move(self.uid, dst, name)
         self.load(doc)
 
-    def remove_permission(self, params):
-        # type: (Dict[str, Any]) -> None
-        """ Remove a permission to a document. """
+    def remove_permission(self, params, ssl_verify=True):
+        # type: (Dict[str, Any], bool) -> None
+        """Remove a permission to a document."""
         return self.service.remove_permission(self.uid, params)
 
     def set(self, properties):
         # type: (Dict[str, Any]) -> None
-        """ Add/update the properties of the document. """
+        """Add/update the properties of the document."""
         self.properties.update(properties)
 
-    def trash(self):
-        # type: () -> None
+    def trash(self, ssl_verify=True):
+        # type: (bool) -> None
         doc = self.service.trash(self.uid)
         self.load(doc)
 
-    def unlock(self):
-        # type: () -> Dict[str, Any]
-        """ Unlock the document. """
+    def unlock(self, ssl_verify=True):
+        # type: (bool) -> Dict[str, Any]
+        """Unlock the document."""
         return self.service.unlock(self.uid)
 
-    def untrash(self):
-        # type: () -> None
+    def untrash(self, ssl_verify=True):
+        # type: (bool) -> None
         doc = self.service.untrash(self.uid)
         self.load(doc)
 
 
 class Group(Model):
-    """ User group. """
+    """User group."""
 
     __slots__ = {
         "entity_type": "group",
@@ -664,14 +674,14 @@ class Group(Model):
         # type: () -> str
         return self.groupname
 
-    def delete(self):
-        # type: () -> None
-        """ Delete the group. """
-        self.service.delete(self.uid)
+    def delete(self, ssl_verify=True):
+        # type: (bool) -> None
+        """Delete the group."""
+        self.service.delete(self.uid, ssl_verify=ssl_verify)
 
 
 class Operation(Model):
-    """ Automation operation. """
+    """Automation operation."""
 
     __slots__ = {
         "command": None,
@@ -683,12 +693,12 @@ class Operation(Model):
 
     def execute(self, **kwargs):
         # type: (Any) -> Any
-        """ Execute the operation. """
+        """Execute the operation."""
         return self.service.execute(self, **kwargs)
 
 
 class Task(RefreshableModel):
-    """ Workflow task. """
+    """Workflow task."""
 
     __slots__ = {
         "actors": [],
@@ -715,7 +725,7 @@ class Task(RefreshableModel):
 
     def complete(self, action, variables=None, comment=None):
         # type: (str, Optional[Dict[str, Any]], Optional[str]) -> None
-        """ Complete the action of a task. """
+        """Complete the action of a task."""
         updated_task = self.service.complete(
             self, action, variables=variables, comment=comment
         )
@@ -723,19 +733,19 @@ class Task(RefreshableModel):
 
     def delegate(self, actors, comment=None):
         # type: (str, Optional[str]) -> None
-        """ Delegate the task to someone else. """
+        """Delegate the task to someone else."""
         self.service.transfer(self, "delegate", actors, comment=comment)
         self.load()
 
     def reassign(self, actors, comment=None):
         # type: (str, Optional[str]) -> None
-        """ Reassign the task to someone else. """
+        """Reassign the task to someone else."""
         self.service.transfer(self, "reassign", actors, comment=comment)
         self.load()
 
 
 class User(RefreshableModel):
-    """ User. """
+    """User."""
 
     __slots__ = {
         "entity_type": "user",
@@ -761,14 +771,14 @@ class User(RefreshableModel):
         self.properties["password"] = password
         self.save()
 
-    def delete(self):
-        # type: () -> None
-        """ Delete the user. """
-        self.service.delete(self.uid)
+    def delete(self, ssl_verify=True):
+        # type: (bool) -> None
+        """Delete the user."""
+        self.service.delete(self.uid, ssl_verify=ssl_verify)
 
 
 class Workflow(Model):
-    """ Workflow. """
+    """Workflow."""
 
     __slots__ = {
         "attachedDocumentIds": [],
@@ -786,7 +796,7 @@ class Workflow(Model):
     @property
     def tasks(self):
         # type: () -> List[Task]
-        """ Return the tasks associated with the workflow. """
+        """Return the tasks associated with the workflow."""
         return self.service.tasks(self)
 
     @property
@@ -796,10 +806,10 @@ class Workflow(Model):
 
     def delete(self):
         # type: () -> None
-        """ Delete the workflow. """
+        """Delete the workflow."""
         self.service.delete(self.uid)
 
     def graph(self):
         # type: () -> Dict[str, Any]
-        """ Return a JSON representation of the workflow graph. """
+        """Return a JSON representation of the workflow graph."""
         return self.service.graph(self)
